import React, { useState } from 'react';

function NameValidation() {
    const [firstName, setFirstName] = useState('');
    const [lastName, setLastName] = useState('');
    const [validationMessage, setValidationMessage] = useState('');

    // Handle form submission
    const handleSubmit = (event) => {
        event.preventDefault();

        const message = validateName(firstName, lastName);
        setValidationMessage(message);
    };

    // Validate First Name and Last Name
    const validateName = (firstName, lastName) => {
        // Check if first name and last name are empty
        if (!firstName || !lastName) {
            return "First name and last name are required.";
        }

        // Check if first name contains only alphabets
        if (!/^[a-zA-Z]+$/.test(firstName)) {
            return "Invalid first name.";
        }

        // Check if last name contains only alphabets
        if (!/^[a-zA-Z]+$/.test(lastName)) {
            return "Invalid last name.";
        }

        // Validation passed
        return "Valid name.";
    };

    return (
        <div>
            <h1>Name Validation</h1>

            <form onSubmit={handleSubmit}>
                <label htmlFor="firstName">First Name:</label>
                <input type="text" id="firstName" value={firstName} onChange={(e) => setFirstName(e.target.value)} required />

                <br />

                <label htmlFor="lastName">Last Name:</label>
                <input type="text" id="lastName" value={lastName} onChange={(e) => setLastName(e.target.value)} required />

                <br />

                <button type="submit">Submit</button>
            </form>

            <p>{validationMessage}</p>
        </div>
    );
}

export default NameValidation;